@@ -6,7 +6,7 @@
  * Provides the client half of the process.  Should be considered
  * untrusted by the privman server.
  *
- * $Id: priv_client.cc,v 1.18 2002/08/02 17:52:34 dougk Exp $
+ * $Id: priv_client.cc,v 1.19 2002/08/27 23:16:09 dougk Exp $
  */
 
 #include <stdarg.h>
@@ -440,6 +440,14 @@ int priv_##name (pam_handle_t *pamh, int flags)                 \
             __FUNCTION__, code) ;                               \
 }
 
+#define PRIV_PAM_SIMPLE2(name,code)                             \
+int priv_##name (pam_handle_t *pamh, unsigned int flags)        \
+{                                                               \
+    return priv_pam_simple_func(pamh, flags,                    \
+            __FUNCTION__, code) ;                               \
+}
+
+
 PRIV_PAM_SIMPLE(pam_authenticate,       CMD_PAM_AUTHENTICATE)
 PRIV_PAM_SIMPLE(pam_acct_mgmt,          CMD_PAM_ACCT_MGMT)
 PRIV_PAM_SIMPLE(pam_end,                CMD_PAM_END)
@@ -447,6 +455,7 @@ PRIV_PAM_SIMPLE(pam_setcred,            CMD_PAM_SETCRED)
 PRIV_PAM_SIMPLE(pam_chauthtok,          CMD_PAM_CHAUTHTOK)
 PRIV_PAM_SIMPLE(pam_open_session,       CMD_PAM_OPEN_SESSION)
 PRIV_PAM_SIMPLE(pam_close_session,      CMD_PAM_CLOSE_SESSION)
+PRIV_PAM_SIMPLE2(pam_fail_delay,        CMD_PAM_FAIL_DELAY)
 
 int priv_pam_set_item(pam_handle_t *pamh, int item_type, const void *item)
 {
