@@ -6,7 +6,7 @@
  * Provides the server half of the process.  This half retains priviledge
  * and should be nei-invulnerable.
  *
- * $Id: privman.cc,v 1.29 2002/08/02 18:02:02 dougk Exp $
+ * $Id: privman.cc,v 1.32 2002/08/30 20:05:07 dougk Exp $
  */
 #include <stdio.h>
 #include <errno.h>
@@ -22,6 +22,7 @@
 #include <sys/stat.h>
 #include <netinet/in.h>
 #include <sys/wait.h>
+#include <syslog.h>
 
 extern "C" {
     /* sockaddr_in */
@@ -51,7 +52,7 @@ static bool     p_wait_on_child = true;
 config_t               *config;
 
 /* Dispatch table */
-map< enum commands, void(*)(message_t*) > function_map;
+std::map< enum commands, void(*)(message_t*) > function_map;
 
 /* PAM conversion function.  We pass the work back to the other
  * side.  The assumption is that the other side is currently
@@ -258,6 +259,7 @@ static void openFile(message_t *msg) {
     if (!openPerm(canpath, flags)) {
         /* MAC check here. TBD: use real globs instead of this hack */
         msg_initResponce(msg, -EPERM);
+        syslog(LOG_NOTICE, "Unauthorized attempt open(%s, %d)", canpath, flags);
     } else {
 
         /* Ok, now do it. */
@@ -290,11 +292,13 @@ static void bindPort(message_t *msg) {
     /* Permission check */
     if (addr->sin_family != AF_INET
     || sockfd < 0
-    || addrlen != sizeof(sockaddr_in)
+    || addrlen < sizeof(sockaddr_in)
     || ( config->bind_port.count(ntohs(addr->sin_port)) == 0
      &&  config->bind_port.count(ntohs(0)) == 0 ) ) { /* wildcard */
         /* Permission denied */
         msg_initResponce(msg, -EPERM);
+        syslog(LOG_NOTICE, "Unauthorized attempt bind to port %d",
+                addr->sin_port);
     } else {
         retval      = bind(sockfd, (struct sockaddr*)addr, addrlen);
 
@@ -504,6 +508,8 @@ void rerunAsProcess(message_t *msg)
     if (user[0] != '\0' && config->user.count(user) == 0
             && config->user.count("*") == 0) {
         msg_initResponce(msg, -EPERM);
+        syslog(LOG_NOTICE, "Unauthorized attempt rerunAs as user %s",
+                user);
         msg_sendmsg(msg, privmand_fd, "rerunAsProcess(sendmsg)");
 
         free(user);
@@ -567,12 +573,14 @@ void execAsProcess(message_t *msg)
     /* Config file MAC */
     if (!openPerm(program, 3)) {
         msg_initResponce(msg, -EPERM);
+        syslog(LOG_NOTICE, "Unauthorized attempt execAs %s", program);
         msg_sendmsg(msg, privmand_fd, "execAsProcess(sendmsg)");
         return;
     }
     if (username[0] != '\0' && config->user.count(username) == 0
             && config->user.count("*") == 0) {
         msg_initResponce(msg, -EPERM);
+        syslog(LOG_NOTICE, "Unauthorized attempt execAs %s", username);
         msg_sendmsg(msg, privmand_fd, "execAsProcess(sendmsg)");
         return;
     }
@@ -702,6 +710,7 @@ static void control_loop(void) {
 
         if (!validRequest(c)) {
             msg_initResponce(msg, -EPERM);
+            syslog(LOG_NOTICE, "Unknown request '%c'", (char)c);
             msg_sendmsg(msg, privmand_fd, "control_loop(validRequest)");
             continue;
         }
@@ -734,6 +743,7 @@ PAM_SIMPLE_HANDLER(pamSetcred,          pam_setcred)
 PAM_SIMPLE_HANDLER(pamOpenSession,      pam_open_session)
 PAM_SIMPLE_HANDLER(pamCloseSession,     pam_close_session)
 PAM_SIMPLE_HANDLER(pamChauthtok,        pam_chauthtok)
+PAM_SIMPLE_HANDLER(pamFailDelay,     (int(*)(pam_handle_t*,int))pam_fail_delay)
 
 void privman_serv_init(void)
 {
@@ -751,6 +761,7 @@ void privman_serv_init(void)
     function_map[ CMD_PAM_OPEN_SESSION  ] = pamOpenSession;
     function_map[ CMD_PAM_CLOSE_SESSION ] = pamCloseSession;
     function_map[ CMD_PAM_CHAUTHTOK     ] = pamChauthtok;
+    function_map[ CMD_PAM_FAIL_DELAY    ] = pamFailDelay;
 
     function_map[ CMD_FORK              ] = forkProcess;
     function_map[ CMD_EXIT              ] = exitServer;
@@ -759,6 +770,12 @@ void privman_serv_init(void)
     function_map[ CMD_RERUN_AS          ] = rerunAsProcess;
     function_map[ CMD_EXEC_AS           ] = execAsProcess;
 
+
+    /* Syslog init. */
+    openlog("privman", LOG_PID, LOG_AUTHPRIV);
+
+
+    /* And the server spends most of its time in here. */
     control_loop();
 
     /* Two ways we get here
